@@ -5,7 +5,7 @@ use warnings;
 use Carp qw(croak);
 use Math::Cephes qw(:dists :explog);
 use vars qw($VERSION);
-$VERSION = 0.031;
+$VERSION = 0.032;
 
 my %counts_dep = (
     hits => [qw/signal_trials misses/], 
@@ -26,15 +26,11 @@ my %rates_dep = (
 
 Statistics::SDT - Signal detection theory (SDT) measures of sensitivity and response-bias
 
-=head1 VERSION
-
-This is documentation for Version 0.031 of Statistics-SDT (2009-03-22).
-
 =head1 SYNOPSIS
 
 The following is based on example data from Stanislav & Todorov (1999), and Alexander (2006), with which the module's results agree.
 
- use Statistics::SDT 0.031;
+ use Statistics::SDT 0.032;
 
  my $sdt = Statistics::SDT->new(
   correction => 1,
@@ -51,18 +47,18 @@ The following is based on example data from Stanislav & Todorov (1999), and Alex
  printf("Hit rate = %s\n",            $sdt->rate('h') );          # .99
  printf("False-alarm rate = %s\n",    $sdt->rate('f') );          # .68
  printf("Miss rate = %s\n",           $sdt->rate('m') );          # .00
- printf("Correct-rej'n rate = %s\n",  $sdt->rate('c'));           # .32
- printf("Sensitivity d' = %s\n",      $sdt->sensitivity('d') );   # 1.86
- printf("Sensitivity Ad' = %s\n",     $sdt->sensitivity('Ad') );  # 0.91
- printf("Sensitivity A' = %s\n",      $sdt->sensitivity('A') );   # 0.82
+ printf("Correct-rej'n rate = %s\n",  $sdt->rate('c') );          # .32
+ printf("Sensitivity d' = %s\n",      $sdt->sens('d') );          # 1.86
+ printf("Sensitivity Ad' = %s\n",     $sdt->sens('Ad') );         # 0.91
+ printf("Sensitivity A' = %s\n",      $sdt->sens('A') );          # 0.82
  printf("Bias beta = %s\n",           $sdt->bias('b') );          # 0.07
  printf("Bias logbeta = %s\n",        $sdt->bias('log') );        # -2.60
  printf("Bias c = %s\n",              $sdt->bias('c') );          # -1.40
  printf("Bias Griers B'' = %s\n",     $sdt->bias('g') );          # -0.91
- printf("Criterion k = %s\n",         $sdt->criterion());         # -0.47
- printf("Hit rate via d & c = %s\n",  $sdt->dc2hr());             # .99
- printf("FAR via d & c = %s\n",       $sdt->dc2far());            # .68
- printf("LogBeta via d & c = %s\n",   $sdt->dc2logbeta());        # -2.60
+ printf("Criterion k = %s\n",         $sdt->crit() );             # -0.47
+ printf("Hit rate via d & c = %s\n",  $sdt->dc2hr() );            # .99
+ printf("FAR via d & c = %s\n",       $sdt->dc2far() );           # .68
+ printf("LogBeta via d & c = %s\n",   $sdt->dc2logbeta() );       # -2.60
 
  # If the number of alternatives is greater than 2, there are two method options:
  printf("JAlex. d_fc = %.2f\n", $sdt->sensitivity('f' => {hr => .866, states => 3, correction => 0, method => 'alexander'})); # 2.00
@@ -316,7 +312,7 @@ sub _correct_rejection_rate {
  $s = $sdt->sensitivity('dprime|dforcedchoice|darea|aprime') # based on values of the measure variables already inited or otherwise set 
  $s = $sdt->sensitivity('dprime' => { signal_trials => integer}) # update any of the measure variables
 
-I<Alias>: discriminability
+I<Alias>: C<sens>, C<discriminability>
 
 Get one of the sensitivity measures, as indicated by the first argument string, optionally updating any of the measure variables and options with a subsequent hashref. The measures are as follows, accessed by giving the name (or at least its first two letters) as the first argument.
 
@@ -412,6 +408,7 @@ sub sensitivity {
     } #end CASE
 }
 *discriminability = \&sensitivity; # Alias
+*sens =\&sensitivity;
 
 sub _d_sensitivity {
     my $self = shift;
@@ -595,7 +592,7 @@ sub _griers_bias { # B''
  $sdt->criterion() # assume d' and c can be calculated from already inited param values
  $sdt->criterion(d => float, c => float)
 
-I<Alias>: C<dc2k>
+I<Alias>: C<dc2k>, C<crit>
 
 Returns the value of the criterion for given values of sensitivity I<d'> and bias I<c>, viz.: I<k> = I<d'> / 2 + I<c>.
 
@@ -608,6 +605,7 @@ sub criterion {
     return _precisioned($_[0]->{'precision_s'}, ($dc->{'d'} / 2) + $dc->{'c'} );
 }
 *dc2k = \&criterion; # Alias
+*crit = \&criterion; 
 
 
 =head2 dc2hr
